summaryrefslogtreecommitdiffstats
path: root/macosx/HBQueueController.mm
diff options
context:
space:
mode:
authordynaflash <[email protected]>2012-02-19 22:14:57 +0000
committerdynaflash <[email protected]>2012-02-19 22:14:57 +0000
commitdbdaabaa73fa1a371aeba3ecd802bb5e003e08bf (patch)
treef3b23a15c223e4836d8c93f897a247c59da7b8da /macosx/HBQueueController.mm
parent68395c181bbf629c33607829aa971cf12c19c29d (diff)
MacGui: Fix an issue where lavc options were shown and passed when Theora was chosen.
git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@4457 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'macosx/HBQueueController.mm')
-rw-r--r--macosx/HBQueueController.mm4
1 files changed, 3 insertions, 1 deletions
diff --git a/macosx/HBQueueController.mm b/macosx/HBQueueController.mm
index 41576e242..6c331c1f1 100644
--- a/macosx/HBQueueController.mm
+++ b/macosx/HBQueueController.mm
@@ -1326,7 +1326,8 @@ return ![(HBQueueOutlineView*)outlineView isDragging];
}
[finalString appendString:@"\n" withAttributes:detailAttr];
}
- else // we must be ffmpeg (lavc)
+ /*If we are not x264 and we are not Theora then we must be FFmpeg (lavc) */
+ else if (![[item objectForKey:@"VideoEncoder"] isEqualToString: @"VP3 (Theora)"])
{
[finalString appendString: @"FFmpeg (lavc) Options: " withAttributes:detailBoldAttr];
if ([item objectForKey:@"lavcOption"])
@@ -1342,6 +1343,7 @@ return ![(HBQueueOutlineView*)outlineView isDragging];
+
/* Seventh Line Audio Details*/
NSEnumerator *audioDetailEnumerator = [audioDetails objectEnumerator];
NSString *anAudioDetail;